==> jc-1.4.0.tar.gz: soot/javaToJimple/jj/DPosition.h <==
// public class soot.javaToJimple.jj.DPosition

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32c9a088c5dac046 polyglot_util_Position
// @dep_class e0215bb69aa8dac3 soot_javaToJimple_jj_DPosition

// header file dependencies
// @dep_header polyglot_util_Position

#include "polyglot/util/Position.h"

#ifndef _JC_soot_javaToJimple_jj_DPosition_H_
#define _JC_soot_javaToJimple_jj_DPosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_DPosition$sub_refs	_jc_soot_javaToJimple_jj_DPosition$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs	_jc_soot_javaToJimple_jj_DPosition$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$refs	_jc_soot_javaToJimple_jj_DPosition$refs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$nonrefs	_jc_soot_javaToJimple_jj_DPosition$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$object	_jc_soot_javaToJimple_jj_DPosition$object;

typedef const struct _jc_soot_javaToJimple_jj_DPosition$vmethods	_jc_soot_javaToJimple_jj_DPosition$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_DPosition$vtable	_jc_soot_javaToJimple_jj_DPosition$vtable;
typedef const struct _jc_soot_javaToJimple_jj_DPosition$vtype	_jc_soot_javaToJimple_jj_DPosition$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_DPosition$method$_init$aea90b4a9c7c9ca6(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *, struct _jc_java_lang_String$object *, jint, jint, jint);
extern void _jc_soot_javaToJimple_jj_DPosition$method$_init$c2b051727c498942(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *, struct _jc_java_lang_String$object *, jint, jint, jint, jint);

// Virtual methods
extern jint _jc_soot_javaToJimple_jj_DPosition$method$endCol$cef98fd6ba768cd6(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);
extern jint _jc_soot_javaToJimple_jj_DPosition$method$endLine$cc49f347e361c33f(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_DPosition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$endCol$cef98fd6ba768cd6;
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$endLine$cc49f347e361c33f;
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_DPosition$vmethods {
	jint	(*endCol$cef98fd6ba768cd6)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);
	jint	(*endLine$cc49f347e361c33f)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *);
};

// Vtable
struct _jc_soot_javaToJimple_jj_DPosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Position$vmethods	polyglot_util_Position;
	_jc_soot_javaToJimple_jj_DPosition$vmethods	soot_javaToJimple_jj_DPosition;
};

// Vtype
struct _jc_soot_javaToJimple_jj_DPosition$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_DPosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_DPosition$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_DPosition$refs {
    _jc_soot_javaToJimple_jj_DPosition$sub_refs	soot_javaToJimple_jj_DPosition;
    _jc_polyglot_util_Position$sub_refs	polyglot_util_Position;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs {
	jint	endCol;
	jint	endLine;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_DPosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Position$sub_nonrefs	polyglot_util_Position;
    _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs	soot_javaToJimple_jj_DPosition;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_DPosition$object {
	_jc_soot_javaToJimple_jj_DPosition$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_DPosition$vtype	*vtype;
	_jc_soot_javaToJimple_jj_DPosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_DPosition$vtype _jc_soot_javaToJimple_jj_DPosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_DPosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_DPosition$class_object;

#endif	/* _JC_soot_javaToJimple_jj_DPosition_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/jj/DPosition.h <==
// public class soot.javaToJimple.jj.DPosition

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32c9a088c5dac046 polyglot_util_Position
// @dep_class e0215bb69aa8dac3 soot_javaToJimple_jj_DPosition

// header file dependencies
// @dep_header polyglot_util_Position

#include "polyglot/util/Position.h"

#ifndef _JC_soot_javaToJimple_jj_DPosition_H_
#define _JC_soot_javaToJimple_jj_DPosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_DPosition$sub_refs	_jc_soot_javaToJimple_jj_DPosition$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs	_jc_soot_javaToJimple_jj_DPosition$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$refs	_jc_soot_javaToJimple_jj_DPosition$refs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$nonrefs	_jc_soot_javaToJimple_jj_DPosition$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_DPosition$object	_jc_soot_javaToJimple_jj_DPosition$object;

typedef const struct _jc_soot_javaToJimple_jj_DPosition$vmethods	_jc_soot_javaToJimple_jj_DPosition$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_DPosition$vtable	_jc_soot_javaToJimple_jj_DPosition$vtable;
typedef const struct _jc_soot_javaToJimple_jj_DPosition$vtype	_jc_soot_javaToJimple_jj_DPosition$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_DPosition$method$_init$aea90b4a9c7c9ca6(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *, struct _jc_java_lang_String$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_jj_DPosition$method$_init$c2b051727c498942(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *, struct _jc_java_lang_String$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_javaToJimple_jj_DPosition$method$endCol$cef98fd6ba768cd6(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_javaToJimple_jj_DPosition$method$endLine$cc49f347e361c33f(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_jj_DPosition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$endCol$cef98fd6ba768cd6;
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$endLine$cc49f347e361c33f;
extern _jc_method _jc_soot_javaToJimple_jj_DPosition$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_DPosition$vmethods {
	jint	(*endCol$cef98fd6ba768cd6)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;
	jint	(*endLine$cc49f347e361c33f)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_javaToJimple_jj_DPosition$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_jj_DPosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Position$vmethods	polyglot_util_Position;
	_jc_soot_javaToJimple_jj_DPosition$vmethods	soot_javaToJimple_jj_DPosition;
};

// Vtype
struct _jc_soot_javaToJimple_jj_DPosition$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_DPosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_DPosition$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_DPosition$refs {
    _jc_soot_javaToJimple_jj_DPosition$sub_refs	soot_javaToJimple_jj_DPosition;
    _jc_polyglot_util_Position$sub_refs	polyglot_util_Position;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs {
	jint	endCol;
	jint	endLine;
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_DPosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Position$sub_nonrefs	polyglot_util_Position;
    _jc_soot_javaToJimple_jj_DPosition$sub_nonrefs	soot_javaToJimple_jj_DPosition;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_DPosition$object {
	_jc_soot_javaToJimple_jj_DPosition$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_DPosition$vtype	*vtype;
	_jc_soot_javaToJimple_jj_DPosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_DPosition$vtype _jc_soot_javaToJimple_jj_DPosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_DPosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_DPosition$class_object;

#endif	/* _JC_soot_javaToJimple_jj_DPosition_H_ */
